@@ -319,7 +319,7 @@ contents_modified_cb (GdauiEntryShell *shell, gpointer unused)
 }
 
 static void mitem_activated_cb (GtkWidget *mitem, GdauiEntryShell *shell);
-static guint gdaui_entry_shell_refresh_attributes (GdauiEntryShell *shell);
+static GdaValueAttribute gdaui_entry_shell_refresh_attributes (GdauiEntryShell *shell);
 static gint
 event_cb (GtkWidget *widget, GdkEvent *event, GdauiEntryShell *shell)
 {
@@ -449,3 +449,21 @@ gdaui_entry_shell_refresh (GdauiEntryShell *shell)
 	gdaui_entry_shell_refresh_attributes (shell);
 	gdaui_entry_shell_refresh_status_display (shell);
 }
+
+/**
+ * gdaui_entry_shell_set_unknown
+ * @shell: the GdauiEntryShell widget to refresh
+ * @unknown: set to %TRUE if @shell's contents is unavailable and should not be modified
+ *
+ * Defines if @shell's contents is in an undefined state (shows or hides @shell's contents)
+ */
+void
+gdaui_entry_shell_set_unknown (GdauiEntryShell *shell, gboolean unknown)
+{
+	g_return_if_fail (GDAUI_IS_ENTRY_SHELL (shell));
+
+	if (unknown)
+		gtk_widget_hide (shell->priv->hbox);
+	else
+		gtk_widget_show (shell->priv->hbox);
+}
