@@ -444,45 +444,13 @@ static gboolean
 proxy_reset_was_soft (GdauiRawGrid *grid, GdaDataModel *new_model)
 {
 	GdaDataModelIter *iter;
-	GSList *olist, *nlist;
 	gboolean retval = FALSE;
 
 	if (!new_model || (new_model != (GdaDataModel*) grid->priv->proxy))
 		return FALSE;
 
 	iter = gda_data_model_create_iter (new_model);
-	for (olist = GDA_SET (grid->priv->iter)->holders, nlist = GDA_SET (iter)->holders;
-	     olist && nlist;
-	     olist = olist->next, nlist = nlist->next) {
-		GdaHolder *oh, *nh;
-		oh = GDA_HOLDER (olist->data);
-		nh = GDA_HOLDER (nlist->data);
-
-		if (gda_holder_get_not_null (oh) != gda_holder_get_not_null (nh))
-			goto out;
-
-		GType ot, nt;
-		ot = gda_holder_get_g_type (oh);
-		nt = gda_holder_get_g_type (nh);
-		if (ot && (ot != nt))
-			goto out;
-		if (ot != nt)
-			g_object_set (oh, "g-type", nt, NULL);
-
-		const gchar *oid, *nid;
-		oid = gda_holder_get_id (oh);
-		nid = gda_holder_get_id (nh);
-		if ((oid && !nid) || (!oid && nid) ||
-		    (oid && strcmp (oid, nid)))
-			goto out;
-	}
-
-	if (olist || nlist)
-		goto out;
-
-	retval = TRUE;
-
- out:
+	retval = ! _gdaui_utility_iter_differ (grid->priv->iter, iter);
 	g_object_unref (iter);
 	return retval;
 }
@@ -1781,30 +1749,31 @@ tree_view_popup_button_pressed_cb (GtkWidget *widget, GdkEventButton *event, Gda
 	/* create the menu */
 	menu = gtk_menu_new ();
 	if (sel_mode == GTK_SELECTION_MULTIPLE)
-		gtk_menu_append (GTK_MENU (menu),
-				 new_menu_item (_("Select _All"), FALSE,
-						G_CALLBACK (menu_select_all_cb), grid));
-
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu),
+				       new_menu_item (_("Select _All"), FALSE,
+						      G_CALLBACK (menu_select_all_cb), grid));
+	
 	if ((sel_mode == GTK_SELECTION_SINGLE) || (sel_mode == GTK_SELECTION_MULTIPLE))
-		gtk_menu_append (GTK_MENU (menu),
-				 new_menu_item (_("_Clear Selection"), FALSE,
-						G_CALLBACK (menu_unselect_all_cb), grid));
-	gtk_menu_append (GTK_MENU (menu),
-			 new_check_menu_item (_("Show Column _Titles"),
-					      gtk_tree_view_get_headers_visible (tree_view),
-					      G_CALLBACK (menu_show_columns_cb), grid));
-
-	gtk_menu_append (GTK_MENU (menu),
-			 new_menu_item (_("_Set filter"), FALSE,
-					G_CALLBACK (menu_set_filter_cb), grid));
-	gtk_menu_append (GTK_MENU (menu),
-			 new_menu_item (_("_Unset filter"), FALSE,
-					G_CALLBACK (menu_unset_filter_cb), grid));
-
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu),
+				       new_menu_item (_("_Clear Selection"), FALSE,
+						      G_CALLBACK (menu_unselect_all_cb), grid));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
+			       new_check_menu_item (_("Show Column _Titles"),
+						    gtk_tree_view_get_headers_visible (tree_view),
+						    G_CALLBACK (menu_show_columns_cb), grid));
+	
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
+			       new_menu_item (_("_Set filter"), FALSE,
+					      G_CALLBACK (menu_set_filter_cb), grid));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
+			       new_menu_item (_("_Unset filter"), FALSE,
+					      G_CALLBACK (menu_unset_filter_cb), grid));
+	
 	if (sel_mode != GTK_SELECTION_NONE) {
-		gtk_menu_append (GTK_MENU (menu), gtk_separator_menu_item_new ());
-		gtk_menu_append (GTK_MENU (menu), new_menu_item (GTK_STOCK_SAVE_AS, TRUE,
-								 G_CALLBACK (menu_save_as_cb), grid));
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new ());
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), new_menu_item (GTK_STOCK_SAVE_AS, TRUE,
+									     G_CALLBACK (menu_save_as_cb),
+									     grid));
 	}
 
 	/* allow listeners to add their custom menu items */
