@@ -270,12 +270,11 @@ gda_sql_builder_get_property (GObject *object,
 }
 
 static guint
-add_part (GdaSqlBuilder *builder, guint id, GdaSqlAnyPart *part)
+add_part (GdaSqlBuilder *builder, GdaSqlAnyPart *part)
 {
 	SqlPart *p;
 	guint *realid = g_new0 (guint, 1);
-	if (id == 0)
-		id = builder->priv->next_assigned_id --;
+	const guint id = builder->priv->next_assigned_id --;
 	*realid = id;
 	p = g_new0 (SqlPart, 1);
 	p->part = part;
@@ -356,30 +355,21 @@ gda_sql_builder_get_statement (GdaSqlBuilder *builder, GError **error)
  *
  * Creates a new #GdaSqlStatement structure from @builder's contents.
  *
- * If @copy_it is %FALSE, then the returned pointer is considered to be stolen from @builder's internal
- * representation and will make it unusable anymore (resulting in a %GDA_SQL_BUILDER_MISUSE_ERROR error or
- * some warnings if one tries to reuse it).
- * If, on the other
- * hand it is set to %TRUE, then the returned #GdaSqlStatement is a copy of the on @builder uses
- * internally, making it reusable.
+ * The returned pointer belongs to @builder's internal representation.
+ * Use gda_sql_statement_copy() if you need to keep it.
  *
  * Returns: a #GdaSqlStatement pointer
  *
  * Since: 4.2
  */
 GdaSqlStatement *
-gda_sql_builder_get_sql_statement (GdaSqlBuilder *builder, gboolean copy_it)
+gda_sql_builder_get_sql_statement (GdaSqlBuilder *builder)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), NULL);
 	if (!builder->priv->main_stmt)
 		return NULL;
-	if (copy_it)
-		return gda_sql_statement_copy (builder->priv->main_stmt);
-	else {
-		GdaSqlStatement *stmt = builder->priv->main_stmt;
-		builder->priv->main_stmt = NULL;
-		return stmt;
-	}
+
+	return builder->priv->main_stmt;
 }
 
 /**
@@ -519,11 +509,11 @@ gda_sql_builder_select_add_field (GdaSqlBuilder *builder, const gchar *field_nam
 	else
 		tmp = (gchar*) field_name;
 
-	const guint field_id = gda_sql_builder_add_id (builder, 0, tmp);
+	const guint field_id = gda_sql_builder_add_id (builder, tmp);
 	if (alias && *alias)
 		gda_sql_builder_add_field_id (builder,
 					      field_id,
-					      gda_sql_builder_add_id (builder, 0, alias));
+					      gda_sql_builder_add_id (builder, alias));
 	else
 		gda_sql_builder_add_field_id (builder,
 					      field_id,
@@ -586,8 +576,8 @@ gda_sql_builder_add_field (GdaSqlBuilder *builder, const gchar *field_name, GTyp
 
 	if (!value)
 		return;
-	id1 = gda_sql_builder_add_id (builder, 0, field_name);
-	id2 = gda_sql_builder_add_expr_value (builder, 0, NULL, value);
+	id1 = gda_sql_builder_add_id (builder, field_name);
+	id2 = gda_sql_builder_add_expr_value (builder, NULL, value);
 	gda_value_free (value);
 	gda_sql_builder_add_field_id (builder, id1, id2);
 }
@@ -619,8 +609,8 @@ gda_sql_builder_add_field_value (GdaSqlBuilder *builder, const gchar *field_name
 	}
 
 	guint id1, id2;
-	id1 = gda_sql_builder_add_id (builder, 0, field_name);
-	id2 = gda_sql_builder_add_expr_value (builder, 0, NULL, value);
+	id1 = gda_sql_builder_add_id (builder, field_name);
+	id2 = gda_sql_builder_add_expr_value (builder, NULL, value);
 	gda_sql_builder_add_field_id (builder, id1, id2);
 }
 
@@ -741,7 +731,6 @@ gda_sql_builder_add_field_id (GdaSqlBuilder *builder, guint field_id, guint valu
 /**
  * gda_sql_builder_add_expr_value
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @dh: a #GdaDataHandler to use, or %NULL
  * @value: value to set the expression to, or %NULL or a GDA_TYPE_NULL value to represent an SQL NULL
  *
@@ -755,7 +744,7 @@ gda_sql_builder_add_field_id (GdaSqlBuilder *builder, guint field_id, guint valu
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, guint id, GdaDataHandler *dh, const GValue *value)
+gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, GdaDataHandler *dh, const GValue *value)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -786,7 +775,7 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, guint id, GdaDataHandler
 		expr = gda_sql_expr_new (NULL);
 		expr->value = gda_value_new (G_TYPE_STRING);
 		g_value_take_string (expr->value, str);
-		return add_part (builder, id, (GdaSqlAnyPart *) expr);
+		return add_part (builder, (GdaSqlAnyPart *) expr);
 	}
 	else {
 		g_warning (_("Could not convert value to type '%s'"),
@@ -798,7 +787,6 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, guint id, GdaDataHandler
 /**
  * gda_sql_builder_add_expr
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @dh: a #GdaDataHandler to use, or %NULL
  * @type: the GType of the following argument
  * @...: value to set the expression to, of the type specified by @type
@@ -810,8 +798,8 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, guint id, GdaDataHandler
  *
  * For example:
  * <programlisting>
- * gda_sql_builder_add_expr (b, 0, G_TYPE_INT, 15);
- * gda_sql_builder_add_expr (b, 5, G_TYPE_STRING, "joe")
+ * gda_sql_builder_add_expr (b, G_TYPE_INT, 15);
+ * gda_sql_builder_add_expr (b, G_TYPE_STRING, "joe")
  * </programlisting>
  *
  * will be rendered as SQL as:
@@ -825,7 +813,7 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, guint id, GdaDataHandler
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_expr (GdaSqlBuilder *builder, guint id, GdaDataHandler *dh, GType type, ...)
+gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type, ...)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -840,7 +828,7 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, guint id, GdaDataHandler *dh,
 
 	if (!value)
 		return 0;
-	retval = gda_sql_builder_add_expr_value (builder, id, dh, value);
+	retval = gda_sql_builder_add_expr_value (builder, dh, value);
 
 	gda_value_free (value);
 
@@ -850,7 +838,6 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, guint id, GdaDataHandler *dh,
 /**
  * gda_sql_builder_add_id
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @string: a string
  *
  * Defines an expression representing an identifier in @builder,
@@ -859,8 +846,8 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, guint id, GdaDataHandler *dh,
  * The new expression will contain the @string literal.
  * For example:
  * <programlisting>
- * gda_sql_builder_add_id (b, 0, "name")
- * gda_sql_builder_add_id (b, 0, "date")
+ * gda_sql_builder_add_id (b, "name")
+ * gda_sql_builder_add_id (b, "date")
  * </programlisting>
  *
  * will be rendered as SQL as:
@@ -876,7 +863,7 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, guint id, GdaDataHandler *dh,
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_id (GdaSqlBuilder *builder, guint id, const gchar *string)
+gda_sql_builder_add_id (GdaSqlBuilder *builder, const gchar *string)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -889,13 +876,12 @@ gda_sql_builder_add_id (GdaSqlBuilder *builder, guint id, const gchar *string)
 		expr->value_is_ident = (gpointer) 0x1;
 	}
 
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 /**
  * gda_sql_builder_add_param
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @param_name: parameter's name
  * @type: parameter's type
  * @nullok: TRUE if the parameter can be set to %NULL
@@ -905,7 +891,7 @@ gda_sql_builder_add_id (GdaSqlBuilder *builder, guint id, const gchar *string)
  * The new expression will contain the @string literal.
  * For example:
  * <programlisting>
- * gda_sql_builder_add_param (b, 0, "age", G_TYPE_INT, FALSE)
+ * gda_sql_builder_add_param (b, "age", G_TYPE_INT, FALSE)
  * </programlisting>
  *
  * will be rendered as SQL as:
@@ -919,7 +905,7 @@ gda_sql_builder_add_id (GdaSqlBuilder *builder, guint id, const gchar *string)
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_param (GdaSqlBuilder *builder, guint id, const gchar *param_name, GType type, gboolean nullok)
+gda_sql_builder_add_param (GdaSqlBuilder *builder, const gchar *param_name, GType type, gboolean nullok)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -933,13 +919,12 @@ gda_sql_builder_add_param (GdaSqlBuilder *builder, guint id, const gchar *param_
 	expr->param_spec->nullok = nullok;
 	expr->param_spec->g_type = type;
 
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 /**
  * gda_sql_builder_add_cond
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @op: type of condition
  * @op1: the ID of the 1st argument (not 0)
  * @op2: the ID of the 2nd argument (may be %0 if @op needs only one operand)
@@ -952,7 +937,7 @@ gda_sql_builder_add_param (GdaSqlBuilder *builder, guint id, const gchar *param_
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_cond (GdaSqlBuilder *builder, guint id, GdaSqlOperatorType op, guint op1, guint op2, guint op3)
+gda_sql_builder_add_cond (GdaSqlBuilder *builder, GdaSqlOperatorType op, guint op1, guint op2, guint op3)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -978,13 +963,12 @@ gda_sql_builder_add_cond (GdaSqlBuilder *builder, guint id, GdaSqlOperatorType o
 							       use_part (p3, GDA_SQL_ANY_PART (expr->cond)));
 	}
 
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 /**
  * gda_sql_builder_add_cond_v
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @op: type of condition
  * @op_ids: an array of ID for the arguments (not %0)
  * @ops_ids_size: size of @ops_ids
@@ -1000,8 +984,8 @@ gda_sql_builder_add_cond (GdaSqlBuilder *builder, guint id, GdaSqlOperatorType o
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_cond_v (GdaSqlBuilder *builder, guint id, GdaSqlOperatorType op,
-			const guint *op_ids, gint op_ids_size)
+gda_sql_builder_add_cond_v (GdaSqlBuilder *builder, GdaSqlOperatorType op,
+			    const guint *op_ids, gint op_ids_size)
 {
 	gint i;
 	SqlPart **parts;
@@ -1021,12 +1005,8 @@ gda_sql_builder_add_cond_v (GdaSqlBuilder *builder, guint id, GdaSqlOperatorType
 	}
 
 	if (op_ids_size == 1) {
-		SqlPart *part = parts [0];
 		g_free (parts);
-		if (id)
-			return add_part (builder, id, use_part (part, NULL));
-		else
-			return op_ids [0]; /* return the same ID as none was specified */
+		return op_ids [0];
 	}
 
 	GdaSqlExpr *expr;
@@ -1040,7 +1020,7 @@ gda_sql_builder_add_cond_v (GdaSqlBuilder *builder, guint id, GdaSqlOperatorType
 								 GDA_SQL_ANY_PART (expr->cond)));
 	g_free (parts);
 
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 
@@ -1052,18 +1032,19 @@ typedef struct {
 /**
  * gda_sql_builder_select_add_target_id
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @table_id: the ID of the expression holding a table reference (not %0)
  * @alias: the alias to give to the target, or %NULL
  *
- * Adds a new target to a SELECT statement
+ * Adds a new target to a SELECT statement. If there already exists a target representing
+ * the same table and the same alias (or with the same absence of alias) then the same target
+ * ID is returned instead of the ID of a new target.
  *
- * Returns: the ID of the new target, or 0 if there was an error
+ * Returns: the ID of the new (or existing) target, or 0 if there was an error
  *
  * Since: 4.2
  */
 guint
-gda_sql_builder_select_add_target_id (GdaSqlBuilder *builder, guint id, guint table_id, const gchar *alias)
+gda_sql_builder_select_add_target_id (GdaSqlBuilder *builder, guint table_id, const gchar *alias)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -1078,22 +1059,50 @@ gda_sql_builder_select_add_target_id (GdaSqlBuilder *builder, guint id, guint ta
 	if (!p)
 		return 0;
 
-	BuildTarget *btarget;
+	/* check for an already existing target with the same characteristics */
 	GdaSqlStatementSelect *sel = (GdaSqlStatementSelect*) builder->priv->main_stmt->contents;
+	if (sel->from) {
+		gchar *ser;
+		GSList *list;
+
+		g_assert (p->part->type == GDA_SQL_ANY_EXPR);
+		ser = gda_sql_expr_serialize ((GdaSqlExpr*) p->part);
+		for (list = sel->from->targets; list; list = list->next) {
+			BuildTarget *bt = (BuildTarget*) list->data;
+			GdaSqlSelectTarget *t = (GdaSqlSelectTarget*) list->data;
+			gboolean idalias = FALSE;
+			if (alias && t->as && !strcmp (t->as, alias))
+				idalias = TRUE;
+			else if (!alias && ! t->as)
+				idalias = TRUE;
+			
+			gchar *tmp;
+			tmp = gda_sql_expr_serialize (t->expr);
+			if (! strcmp (ser, tmp)) {
+				if (idalias) {
+					g_free (tmp);
+					g_free (ser);
+					return bt->part_id;
+				}
+			}
+			g_free (tmp);
+		}
+		g_free (ser);
+	}
+
+	BuildTarget *btarget;
+	GdaSqlSelectTarget *target;
 	btarget = g_new0 (BuildTarget, 1);
         GDA_SQL_ANY_PART (btarget)->type = GDA_SQL_ANY_SQL_SELECT_TARGET;
         GDA_SQL_ANY_PART (btarget)->parent = GDA_SQL_ANY_PART (sel->from);
-	if (id)
-		btarget->part_id = id;
-	else
-		btarget->part_id = builder->priv->next_assigned_id --;
+	btarget->part_id = builder->priv->next_assigned_id --;
 
-	((GdaSqlSelectTarget*) btarget)->expr = (GdaSqlExpr*) use_part (p, GDA_SQL_ANY_PART (btarget));
+	target = (GdaSqlSelectTarget*) btarget;
+	target->expr = (GdaSqlExpr*) use_part (p, GDA_SQL_ANY_PART (btarget));
 	if (alias && *alias)
-		((GdaSqlSelectTarget*) btarget)->as = g_strdup (alias);
-	if (g_value_get_string (((GdaSqlSelectTarget*) btarget)->expr->value))
-		((GdaSqlSelectTarget*) btarget)->table_name =
-			g_value_dup_string (((GdaSqlSelectTarget*) btarget)->expr->value);
+		target->as = g_strdup (alias);
+	if (target->expr->value && g_value_get_string (target->expr->value))
+		target->table_name = g_value_dup_string (target->expr->value);
 
 	/* add target to sel->from. NOTE: @btarget is NOT added to the "repository" or GdaSqlAnyPart parts
 	* like others */
@@ -1131,13 +1140,11 @@ gda_sql_builder_select_add_target (GdaSqlBuilder *builder, const gchar *table_na
 	g_return_val_if_fail (table_name && *table_name, 0);
 
 	id = gda_sql_builder_select_add_target_id (builder,
-						   0,
-						   gda_sql_builder_add_id (builder, 0, table_name),
+						   gda_sql_builder_add_id (builder, table_name),
 						   alias);
 	return id;
 }
 
-
 typedef struct {
 	GdaSqlSelectJoin join; /* inheritance! */
 	guint part_id; /* copied from this part ID */
@@ -1146,20 +1153,24 @@ typedef struct {
 /**
  * gda_sql_builder_select_join_targets
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @left_target_id: the ID of the left target to use (not %0)
  * @right_target_id: the ID of the right target to use (not %0)
  * @join_type: the type of join
  * @join_expr: joining expression's ID, or %0
  *
- * Joins two targets in a SELECT statement
+ * Joins two targets in a SELECT statement, using the @join_type type of join.
+ *
+ * Note: if the target represented by @left_target_id is actually situated after (on the right) of
+ * the target represented by @right_target_id, then the actual type of join may be switched from
+ * %GDA_SQL_SELECT_JOIN_LEFT to %GDA_SQL_SELECT_JOIN_RIGHT or from %GDA_SQL_SELECT_JOIN_RIGHT to
+ * %GDA_SQL_SELECT_JOIN_LEFT.
  *
  * Returns: the ID of the new join, or 0 if there was an error
  *
  * Since: 4.2
  */
 guint
-gda_sql_builder_select_join_targets (GdaSqlBuilder *builder, guint id,
+gda_sql_builder_select_join_targets (GdaSqlBuilder *builder,
 				     guint left_target_id, guint right_target_id,
 				     GdaSqlSelectJoinType join_type,
 				     guint join_expr)
@@ -1188,13 +1199,32 @@ gda_sql_builder_select_join_targets (GdaSqlBuilder *builder, guint id,
 		if ((left_pos != -1) && (right_pos != -1))
 			break;
 	}
-	if ((left_pos == -1) || (right_pos == -1)) {
-		g_warning (_("Unknown part ID %u"), (left_pos == -1) ? left_pos : right_pos);
+
+	if (left_pos == -1) {
+		g_warning (_("Unknown left part target ID %u"), left_target_id);
+		return 0;
+	}
+
+	if (right_pos == -1) {
+		g_warning (_("Unknown right part target ID %u"), right_target_id);
 		return 0;
 	}
 
 	if (left_pos > right_pos) {
-		TO_IMPLEMENT;
+		GdaSqlSelectJoinType jt;
+		switch (join_type) {
+		case GDA_SQL_SELECT_JOIN_LEFT:
+			jt = GDA_SQL_SELECT_JOIN_RIGHT;
+			break;
+		case GDA_SQL_SELECT_JOIN_RIGHT:
+			jt = GDA_SQL_SELECT_JOIN_LEFT;
+			break;
+		default:
+			jt = join_type;
+			break;
+		}
+		return gda_sql_builder_select_join_targets (builder, right_target_id,
+							    left_target_id, jt, join_expr);
 	}
 
 	/* create join */
@@ -1204,10 +1234,7 @@ gda_sql_builder_select_join_targets (GdaSqlBuilder *builder, guint id,
 	bjoin = g_new0 (BuilderJoin, 1);
 	GDA_SQL_ANY_PART (bjoin)->type = GDA_SQL_ANY_SQL_SELECT_JOIN;
         GDA_SQL_ANY_PART (bjoin)->parent = GDA_SQL_ANY_PART (sel->from);
-	if (id)
-		bjoin->part_id = id;
-	else
-		bjoin->part_id = builder->priv->next_assigned_id --;
+	bjoin->part_id = builder->priv->next_assigned_id --;
 	join = (GdaSqlSelectJoin*) bjoin;
 	join->type = join_type;
 	join->position = right_pos;
@@ -1306,7 +1333,7 @@ gda_sql_builder_select_order_by (GdaSqlBuilder *builder, guint expr_id,
 	sorder = gda_sql_select_order_new (GDA_SQL_ANY_PART (sel));
 	sorder->expr = (GdaSqlExpr*) use_part (part, GDA_SQL_ANY_PART (sorder));
 	sorder->asc = asc;
-	if (collation_name)
+	if (collation_name && *collation_name)
 		sorder->collation_name = g_strdup (collation_name);
 	sel->order_by = g_slist_append (sel->order_by, sorder);
 }
@@ -1494,7 +1521,6 @@ gda_sql_builder_select_group_by (GdaSqlBuilder *builder, guint expr_id)
 /**
  * gda_sql_builder_add_function
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @function_id: the ID of the functions's name
  * @...: a list, terminated with %0, of each function's argument's ID
  *
@@ -1505,10 +1531,11 @@ gda_sql_builder_select_group_by (GdaSqlBuilder *builder, guint expr_id)
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_function (GdaSqlBuilder *builder, guint id, const gchar *func_name, ...)
+gda_sql_builder_add_function (GdaSqlBuilder *builder, const gchar *func_name, ...)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
+	g_return_val_if_fail (func_name && *func_name, 0);
 
 	GdaSqlExpr *expr;
 	GSList *list = NULL;
@@ -1533,13 +1560,12 @@ gda_sql_builder_add_function (GdaSqlBuilder *builder, guint id, const gchar *fun
 	va_end (ap);
 	expr->func->args_list = g_slist_reverse (list);
 
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 /**
  * gda_sql_builder_add_function_v
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @function_id: the ID of the functions's name
  * @args: an array of IDs representing the function's arguments
  * @args_size: @args's size
@@ -1551,7 +1577,7 @@ gda_sql_builder_add_function (GdaSqlBuilder *builder, guint id, const gchar *fun
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_function_v (GdaSqlBuilder *builder, guint id, const gchar *func_name,
+gda_sql_builder_add_function_v (GdaSqlBuilder *builder, const gchar *func_name,
 				const guint *args, gint args_size)
 {
 	gint i;
@@ -1577,14 +1603,13 @@ gda_sql_builder_add_function_v (GdaSqlBuilder *builder, guint id, const gchar *f
 	}
 	expr->func->args_list = g_slist_reverse (list);
 
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 /**
  * gda_sql_builder_add_sub_select
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
- * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT
+ * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT. This will be copied.
  * @steal: if %TRUE, then @sqlst will be "stolen" by @b and should not be used anymore
  *
  * Adds an expression which is a subselect.
@@ -1594,7 +1619,7 @@ gda_sql_builder_add_function_v (GdaSqlBuilder *builder, guint id, const gchar *f
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_sub_select (GdaSqlBuilder *builder, guint id, GdaSqlStatement *sqlst, gboolean steal)
+gda_sql_builder_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement *sqlst)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -1604,26 +1629,21 @@ gda_sql_builder_add_sub_select (GdaSqlBuilder *builder, guint id, GdaSqlStatemen
 
 	GdaSqlExpr *expr;
 	expr = gda_sql_expr_new (NULL);
-	if (steal) {
-		expr->select = sqlst->contents;
-		sqlst->contents = NULL;
-		gda_sql_statement_free (sqlst);
-	}
-	else {
-		switch (sqlst->stmt_type) {
-		case GDA_SQL_STATEMENT_SELECT:
-			expr->select = _gda_sql_statement_select_copy (sqlst->contents);
-			break;
-		case GDA_SQL_STATEMENT_COMPOUND:
-			expr->select = _gda_sql_statement_compound_copy (sqlst->contents);
-			break;
-		default:
-			g_assert_not_reached ();
-		}
+
+	switch (sqlst->stmt_type) {
+	case GDA_SQL_STATEMENT_SELECT:
+		expr->select = _gda_sql_statement_select_copy (sqlst->contents);
+		break;
+	case GDA_SQL_STATEMENT_COMPOUND:
+		expr->select = _gda_sql_statement_compound_copy (sqlst->contents);
+		break;
+	default:
+		g_assert_not_reached ();
 	}
+
 	GDA_SQL_ANY_PART (expr->select)->parent = GDA_SQL_ANY_PART (expr);
 
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
 /**
@@ -1653,15 +1673,14 @@ gda_sql_builder_compound_set_type (GdaSqlBuilder *builder, GdaSqlStatementCompou
 /**
  * gda_sql_builder_compound_add_sub_select
  * @builder: a #GdaSqlBuilder object
- * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT
- * @steal: if %TRUE, then @sqlst will be "stolen" by @b and should not be used anymore
+ * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT. This will be copied.
  *
  * Add a sub select to a COMPOUND statement
  *
  * Since: 4.2
  */
 void
-gda_sql_builder_compound_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement *sqlst, gboolean steal)
+gda_sql_builder_compound_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement *sqlst)
 {
 	GdaSqlStatementCompound *cstmt;
 	GdaSqlStatement *sub;
@@ -1677,10 +1696,7 @@ gda_sql_builder_compound_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement
 			  (sqlst->stmt_type == GDA_SQL_STATEMENT_COMPOUND));
 
 	cstmt = (GdaSqlStatementCompound*) builder->priv->main_stmt->contents;
-	if (steal)
-		sub = sqlst;
-	else
-		sub = gda_sql_statement_copy (sqlst);
+	sub = gda_sql_statement_copy (sqlst);
 
 	cstmt->stmt_list = g_slist_append (cstmt->stmt_list, sub);
 }
@@ -1688,7 +1704,6 @@ gda_sql_builder_compound_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement
 /**
  * gda_sql_builder_add_case
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @test_expr: the expression ID representing the test of the CASE, or %0
  * @else_expr: the expression ID representing the ELSE expression, or %0
  * @...: a list, terminated by a %0, of (WHEN expression ID, THEN expression ID) representing
@@ -1701,7 +1716,7 @@ gda_sql_builder_compound_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_case (GdaSqlBuilder *builder, guint id,
+gda_sql_builder_add_case (GdaSqlBuilder *builder,
 			  guint test_expr, guint else_expr, ...)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -1743,7 +1758,7 @@ gda_sql_builder_add_case (GdaSqlBuilder *builder, guint id,
 	va_end (ap);
 	expr->case_s->when_expr_list = g_slist_reverse (expr->case_s->when_expr_list);
 	expr->case_s->then_expr_list = g_slist_reverse (expr->case_s->then_expr_list);
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 
  cleanups:
 	gda_sql_expr_free (expr);
@@ -1753,7 +1768,6 @@ gda_sql_builder_add_case (GdaSqlBuilder *builder, guint id,
 /**
  * gda_sql_builder_add_case_v
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @test_expr: the expression ID representing the test of the CASE, or %0
  * @else_expr: the expression ID representing the ELSE expression, or %0
  * @when_array: an array containing each WHEN expression ID, having at least @args_size elements
@@ -1769,7 +1783,7 @@ gda_sql_builder_add_case (GdaSqlBuilder *builder, guint id,
  * Since: 4.2
  */
 guint
-gda_sql_builder_add_case_v (GdaSqlBuilder *builder, guint id,
+gda_sql_builder_add_case_v (GdaSqlBuilder *builder,
 			    guint test_expr, guint else_expr,
 			    const guint *when_array, const guint *then_array, gint args_size)
 {
@@ -1805,7 +1819,7 @@ gda_sql_builder_add_case_v (GdaSqlBuilder *builder, guint id,
 	}
 	expr->case_s->when_expr_list = g_slist_reverse (expr->case_s->when_expr_list);
 	expr->case_s->then_expr_list = g_slist_reverse (expr->case_s->then_expr_list);
-	return add_part (builder, id, (GdaSqlAnyPart *) expr);
+	return add_part (builder, (GdaSqlAnyPart *) expr);
 
  cleanups:
 	gda_sql_expr_free (expr);
@@ -1842,7 +1856,6 @@ gda_sql_builder_export_expression (GdaSqlBuilder *builder, guint id)
 /**
  * gda_sql_builder_import_expression
  * @builder: a #GdaSqlBuilder object
- * @id: the requested ID, or 0 if to be determined by @builder
  * @expr: a #GdaSqlExpr obtained using gda_sql_builder_export_expression()
  *
  * Imports the @expr into @builder.
@@ -1852,12 +1865,12 @@ gda_sql_builder_export_expression (GdaSqlBuilder *builder, guint id)
  * Since: 4.2
  */
 guint
-gda_sql_builder_import_expression (GdaSqlBuilder *builder, guint id, GdaSqlExpr *expr)
+gda_sql_builder_import_expression (GdaSqlBuilder *builder, GdaSqlExpr *expr)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
 	g_return_val_if_fail (expr, 0);
 
 	g_return_val_if_fail (GDA_SQL_ANY_PART (expr)->type == GDA_SQL_ANY_EXPR, 0);
-	return add_part (builder, id, (GdaSqlAnyPart *) gda_sql_expr_copy (expr));	
+	return add_part (builder, (GdaSqlAnyPart *) gda_sql_expr_copy (expr));
 }
