@@ -41,7 +41,6 @@
 
 #include <libgda/binreloc/gda-binreloc.h>
 
-#define charMap(X) UpperToLower[(unsigned char)(X)]
 #define KEYWORDS_HASH_NO_STATIC
 #include <libgda/sqlite/keywords_hash.h>
 #include "keywords_hash.c" /* this one is dynamically generated */
@@ -204,8 +203,8 @@ gda_default_escape_string (const gchar *string)
  * gda_default_unescape_string
  * @string: string to unescape
  *
- * Do the reverse of gda_default_escape_string(): transforms any "\'" into "'" and any
- * "\\" into "\". 
+ * Do the reverse of gda_default_escape_string(): transforms any "''" into "'", any
+ * "\\" into "\" and any "\'" into "'". 
  *
  * Returns: a new unescaped string, or %NULL in an error was found in @string
  */
@@ -405,10 +404,9 @@ gda_utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent,
 					}
 					else if (G_VALUE_TYPE (value) == GDA_TYPE_BLOB) {
 						/* force reading the whole blob */
-						GdaBlob *blob;
-						blob = gda_value_get_blob (value);
+						const GdaBlob *blob = gda_value_get_blob (value);
 						if (blob) {
-							GdaBinary *bin = (GdaBinary*) blob;
+							const GdaBinary *bin = &(blob->data);
 							if (blob->op && 
 							    (bin->binary_length != gda_blob_op_get_length (blob->op)))
 								gda_blob_op_read_all (blob->op, blob);
@@ -608,6 +606,7 @@ gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *
 				}
 			}
 		}
+		g_free (source);
 	}
 
 	/* specified value */
@@ -1158,7 +1157,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
  * however that this GdaSqlStatement does not select anything (ie it would be rendered as "SELECT FROM ... WHERE ...")
  * and before being usable, one needs to add some fields to actually select.
  *
- * Returns; a new #GdaStatement if no error occurred, or %NULL otherwise
+ * Returns: a new #GdaStatement if no error occurred, or %NULL otherwise
  */
 GdaSqlStatement *
 gda_compute_select_statement_from_update (GdaStatement *update_stmt, GError **error)
