@@ -41,7 +41,7 @@ static gboolean     gda_sqlite_handler_bin_accepts_g_type       (GdaDataHandler
 static const gchar *gda_sqlite_handler_bin_get_descr              (GdaDataHandler *dh);
 
 struct  _GdaSqliteHandlerBinPriv {
-	gchar             *detailled_descr;
+	gchar             *detailed_descr;
 	guint              nb_g_types;
 	GType             *valid_g_types;
 };
@@ -50,7 +50,7 @@ struct  _GdaSqliteHandlerBinPriv {
 static GObjectClass *parent_class = NULL;
 
 GType
-gda_sqlite_handler_bin_get_type (void)
+_gda_sqlite_handler_bin_get_type (void)
 {
 	static GType type = 0;
 
@@ -112,7 +112,7 @@ gda_sqlite_handler_bin_init (GdaSqliteHandlerBin * hdl)
 {
 	/* Private structure */
 	hdl->priv = g_new0 (GdaSqliteHandlerBinPriv, 1);
-	hdl->priv->detailled_descr = _("SQlite binary handler");
+	hdl->priv->detailed_descr = _("SQlite binary handler");
 	hdl->priv->nb_g_types = 1;
 	hdl->priv->valid_g_types = g_new0 (GType, hdl->priv->nb_g_types);
 	hdl->priv->valid_g_types[0] = GDA_TYPE_BINARY;
@@ -144,14 +144,14 @@ gda_sqlite_handler_bin_dispose (GObject   * object)
 }
 
 /**
- * gda_sqlite_handler_bin_new
+ * _gda_sqlite_handler_bin_new
  *
  * Creates a data handler for binary values
  *
  * Returns: the new object
  */
 GdaDataHandler *
-gda_sqlite_handler_bin_new (void)
+_gda_sqlite_handler_bin_new (void)
 {
 	GObject *obj;
 
