@@ -33,23 +33,15 @@
 #include <winsock.h>
 #endif
 #include <mysql.h>
+#include <gda-mysql-reuseable.h>
 
 /*
  * Provider's specific connection data
  */
 typedef struct {
-	/* TO_ADD: this structure holds any information necessary to specialize the GdaConnection, usually a connection
-	 * handle from the C or C++ API
-	 */
-	
-	GdaConnection    *cnc;
-	MYSQL            *mysql;
-	MYSQL_STMT       *mysql_stmt;
-
-	/* Backend version (to which we're connected). */
-	gchar            *version;
-	unsigned long     version_long;
-	
+	GdaMysqlReuseable *reuseable;
+	GdaConnection     *cnc;
+	MYSQL             *mysql;	
 } MysqlConnectionData;
 
 #endif
