@@ -1,5 +1,5 @@
 /* GDA capi provider
- * Copyright (C) 2008 The GNOME Foundation.
+ * Copyright (C) 2008 - 2009 The GNOME Foundation.
  *
  * AUTHORS:
  *      TO_ADD: your name and email
@@ -87,6 +87,11 @@ _gda_capi_provider_meta_init (GdaServerProvider *provider)
 				    "name2", G_TYPE_STRING, "");
 
 	g_static_mutex_unlock (&init_mutex);
+
+#ifdef GDA_DEBUG
+	/* make sure the reserved keywords hash works correctly */
+        test_keywords ();
+#endif
 }
 
 gboolean
@@ -103,6 +108,8 @@ _gda_capi_meta__info (GdaServerProvider *prov, GdaConnection *cnc,
 	 */
 	if (!model)
 		return FALSE;
+
+	gda_meta_store_set_reserved_keywords_func (store, is_keyword);
 	retval = gda_meta_store_modify_with_context (store, context, model, error);
 	g_object_unref (model);
 		
@@ -145,6 +152,8 @@ _gda_capi_meta_udt (GdaServerProvider *prov, GdaConnection *cnc,
 	 */
 	if (!model)
 		return FALSE;
+
+	gda_meta_store_set_reserved_keywords_func (store, is_keyword);
 	retval = gda_meta_store_modify_with_context (store, context, model, error);
 	g_object_unref (model);
 
@@ -489,3 +498,39 @@ _gda_capi_meta_routine_par (GdaServerProvider *prov, GdaConnection *cnc,
 	TO_IMPLEMENT;
 	return TRUE;
 }
+
+gboolean
+_gda_capi_meta__indexes_tab (GdaServerProvider *prov, GdaConnection *cnc, 
+			     GdaMetaStore *store, GdaMetaContext *context, GError **error)
+{
+	TO_IMPLEMENT;
+	return TRUE;
+}
+
+gboolean
+_gda_capi_meta_indexes_tab (GdaServerProvider *prov, GdaConnection *cnc, 
+			    GdaMetaStore *store, GdaMetaContext *context, GError **error,
+			    const GValue *table_catalog, const GValue *table_schema, const GValue *table_name,
+			    const GValue *index_name_n)
+{
+	TO_IMPLEMENT;
+	return TRUE;
+}
+
+gboolean
+_gda_capi_meta__index_cols (GdaServerProvider *prov, GdaConnection *cnc, 
+			    GdaMetaStore *store, GdaMetaContext *context, GError **error)
+{
+	TO_IMPLEMENT;
+	return TRUE;
+}
+
+gboolean
+_gda_capi_meta_index_cols (GdaServerProvider *prov, GdaConnection *cnc, 
+			   GdaMetaStore *store, GdaMetaContext *context, GError **error,
+			   const GValue *table_catalog, const GValue *table_schema,
+			   const GValue *table_name, const GValue *index_name)
+{
+	TO_IMPLEMENT;
+	return TRUE;
+}
