@@ -249,16 +249,16 @@ find_favorite_position (BrowserFavorites *bfav, gint fav_id, gint order_key)
 
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_SELECT);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "rank"), 0);
+				   gda_sql_builder_add_id (b, "rank"), 0);
 	gda_sql_builder_select_add_target (b, FAVORDER_TABLE_NAME, NULL);
 	gda_sql_builder_set_where (b,
-				   gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_AND,
-				   gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-							 gda_sql_builder_add_id (b, 0, "fav_id"),
-							 gda_sql_builder_add_param (b, 0, "favid", G_TYPE_INT, FALSE), 0),
-				   gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-							 gda_sql_builder_add_id (b, 0, "order_key"),
-							 gda_sql_builder_add_param (b, 0, "okey", G_TYPE_INT, FALSE), 0),
+				   gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_AND,
+				   gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+							 gda_sql_builder_add_id (b, "fav_id"),
+							 gda_sql_builder_add_param (b, "favid", G_TYPE_INT, FALSE), 0),
+				   gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+							 gda_sql_builder_add_id (b, "order_key"),
+							 gda_sql_builder_add_param (b, "okey", G_TYPE_INT, FALSE), 0),
 							 0));
 
 	stmt = gda_sql_builder_get_statement (b, NULL);
@@ -312,34 +312,34 @@ find_favorite (BrowserFavorites *bfav, guint session_id, gint id, const gchar *c
 
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_SELECT);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "id"), 0);
+				   gda_sql_builder_add_id (b, "id"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "type"), 0);
+				   gda_sql_builder_add_id (b, "type"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "name"), 0);
+				   gda_sql_builder_add_id (b, "name"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "descr"), 0);
+				   gda_sql_builder_add_id (b, "descr"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "contents"), 0);
+				   gda_sql_builder_add_id (b, "contents"), 0);
 	gda_sql_builder_select_add_target (b, FAVORITES_TABLE_NAME, NULL);
 
 	if (id >= 0) {
 		/* lookup from ID */
 		gda_sql_builder_set_where (b,
-		    gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-					  gda_sql_builder_add_id (b, 0, "id"),
-					  gda_sql_builder_add_param (b, 0, "id", G_TYPE_INT, FALSE), 0));
+		    gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+					  gda_sql_builder_add_id (b, "id"),
+					  gda_sql_builder_add_param (b, "id", G_TYPE_INT, FALSE), 0));
 	}
 	else {
 		/* lookup using session and contents */
 		gda_sql_builder_set_where (b,
-	            gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_AND,
-					  gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-						   gda_sql_builder_add_id (b, 0, "session"),
-						   gda_sql_builder_add_param (b, 0, "session", G_TYPE_INT, FALSE), 0),
-					  gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-						   gda_sql_builder_add_id (b, 0, "contents"),
-						   gda_sql_builder_add_param (b, 0, "contents", G_TYPE_INT, FALSE), 0), 0));
+	            gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_AND,
+					  gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+						   gda_sql_builder_add_id (b, "session"),
+						   gda_sql_builder_add_param (b, "session", G_TYPE_INT, FALSE), 0),
+					  gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+						   gda_sql_builder_add_id (b, "contents"),
+						   gda_sql_builder_add_param (b, "contents", G_TYPE_INT, FALSE), 0), 0));
 	}
  	stmt = gda_sql_builder_get_statement (b, error);
 	g_object_unref (G_OBJECT (b));
@@ -399,15 +399,15 @@ favorites_reorder (BrowserFavorites *bfav, gint order_key, gint id, gint new_pos
 	g_assert (order_key >= 0);
 
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_SELECT);
-	gda_sql_builder_add_field_id (b, gda_sql_builder_add_id (b, 0, "fav_id"), 0);
+	gda_sql_builder_add_field_id (b, gda_sql_builder_add_id (b, "fav_id"), 0);
 
 	gda_sql_builder_select_add_target (b, FAVORDER_TABLE_NAME, NULL);
 	
-	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, 1, GDA_SQL_OPERATOR_TYPE_EQ,
-				    gda_sql_builder_add_id (b, 0, "order_key"),
-				    gda_sql_builder_add_param (b, 0, "orderkey", G_TYPE_INT, FALSE), 0));
+	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+				    gda_sql_builder_add_id (b, "order_key"),
+				    gda_sql_builder_add_param (b, "orderkey", G_TYPE_INT, FALSE), 0));
 	gda_sql_builder_select_order_by (b,
-					 gda_sql_builder_add_id (b, 0, "rank"), TRUE, NULL);
+					 gda_sql_builder_add_id (b, "rank"), TRUE, NULL);
 	stmt = gda_sql_builder_get_statement (b, error);
 	g_object_unref (G_OBJECT (b));
 	if (!stmt)
@@ -434,17 +434,17 @@ favorites_reorder (BrowserFavorites *bfav, gint order_key, gint id, gint new_pos
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_UPDATE);
 	gda_sql_builder_set_table (b, FAVORDER_TABLE_NAME);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "rank"),
-				   gda_sql_builder_add_param (b, 0, "rank", G_TYPE_INT, FALSE));
-	gda_sql_builder_add_cond (b, 1, GDA_SQL_OPERATOR_TYPE_EQ,
-			      gda_sql_builder_add_id (b, 0, "fav_id"),
-			      gda_sql_builder_add_param (b, 0, "id", G_TYPE_INT, FALSE),
+				   gda_sql_builder_add_id (b, "rank"),
+				   gda_sql_builder_add_param (b, "rank", G_TYPE_INT, FALSE));
+	const guint id_cond1 = gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+			      gda_sql_builder_add_id (b, "fav_id"),
+			      gda_sql_builder_add_param (b, "id", G_TYPE_INT, FALSE),
 			      0);
-	gda_sql_builder_add_cond (b, 2, GDA_SQL_OPERATOR_TYPE_EQ,
-			      gda_sql_builder_add_id (b, 0, "order_key"),
-			      gda_sql_builder_add_param (b, 0, "orderkey", G_TYPE_INT, FALSE),
+	const guint id_cond2 = gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+			      gda_sql_builder_add_id (b, "order_key"),
+			      gda_sql_builder_add_param (b, "orderkey", G_TYPE_INT, FALSE),
 			      0);
-	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_AND, 1, 2, 0));
+	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_AND, id_cond1, id_cond2, 0));
 	stmt = gda_sql_builder_get_statement (b, error);
 	if (!stmt) {
 		retval = FALSE;
@@ -560,20 +560,20 @@ browser_favorites_add (BrowserFavorites *bfav, guint session_id,
 		gda_sql_builder_set_table (builder, FAVORITES_TABLE_NAME);
 
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "session"),
-					   gda_sql_builder_add_param (builder, 0, "session", G_TYPE_INT, FALSE));
+					   gda_sql_builder_add_id (builder, "session"),
+					   gda_sql_builder_add_param (builder, "session", G_TYPE_INT, FALSE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "type"),
-					   gda_sql_builder_add_param (builder, 0, "type", G_TYPE_INT, FALSE));
+					   gda_sql_builder_add_id (builder, "type"),
+					   gda_sql_builder_add_param (builder, "type", G_TYPE_INT, FALSE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "name"),
-					   gda_sql_builder_add_param (builder, 0, "name", G_TYPE_STRING, TRUE));
+					   gda_sql_builder_add_id (builder, "name"),
+					   gda_sql_builder_add_param (builder, "name", G_TYPE_STRING, TRUE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "contents"),
-					   gda_sql_builder_add_param (builder, 0, "contents", G_TYPE_STRING, FALSE));
+					   gda_sql_builder_add_id (builder, "contents"),
+					   gda_sql_builder_add_param (builder, "contents", G_TYPE_STRING, FALSE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "descr"),
-					   gda_sql_builder_add_param (builder, 0, "descr", G_TYPE_STRING, TRUE));
+					   gda_sql_builder_add_id (builder, "descr"),
+					   gda_sql_builder_add_param (builder, "descr", G_TYPE_STRING, TRUE));
 		stmt = gda_sql_builder_get_statement (builder, error);
 		g_object_unref (G_OBJECT (builder));
 		if (!stmt)
@@ -597,29 +597,29 @@ browser_favorites_add (BrowserFavorites *bfav, guint session_id,
 		gda_sql_builder_set_table (builder, FAVORITES_TABLE_NAME);
 
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "name"),
-					   gda_sql_builder_add_param (builder, 0, "name", G_TYPE_STRING, TRUE));
+					   gda_sql_builder_add_id (builder, "name"),
+					   gda_sql_builder_add_param (builder, "name", G_TYPE_STRING, TRUE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "contents"),
-					   gda_sql_builder_add_param (builder, 0, "contents", G_TYPE_STRING, FALSE));
+					   gda_sql_builder_add_id (builder, "contents"),
+					   gda_sql_builder_add_param (builder, "contents", G_TYPE_STRING, FALSE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "descr"),
-					   gda_sql_builder_add_param (builder, 0, "descr", G_TYPE_STRING, TRUE));
+					   gda_sql_builder_add_id (builder, "descr"),
+					   gda_sql_builder_add_param (builder, "descr", G_TYPE_STRING, TRUE));
 
 		gda_sql_builder_set_where (builder,
-					   gda_sql_builder_add_cond (builder, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-								 gda_sql_builder_add_id (builder, 0, "id"),
-								 gda_sql_builder_add_param (builder, 0, "id", G_TYPE_INT, FALSE),
+					   gda_sql_builder_add_cond (builder, GDA_SQL_OPERATOR_TYPE_EQ,
+								 gda_sql_builder_add_id (builder, "id"),
+								 gda_sql_builder_add_param (builder, "id", G_TYPE_INT, FALSE),
 								 0));
 		if (fav->id == favid) {
 			/* alter name and description only if fav->id was OK */
 			gda_sql_builder_add_field_id (builder,
-						   gda_sql_builder_add_id (builder, 0, "name"),
-						   gda_sql_builder_add_param (builder, 0, "name", G_TYPE_STRING,
+						   gda_sql_builder_add_id (builder, "name"),
+						   gda_sql_builder_add_param (builder, "name", G_TYPE_STRING,
 									  TRUE));
 			gda_sql_builder_add_field_id (builder,
-						   gda_sql_builder_add_id (builder, 0, "descr"),
-						   gda_sql_builder_add_param (builder, 0, "descr", G_TYPE_STRING,
+						   gda_sql_builder_add_id (builder, "descr"),
+						   gda_sql_builder_add_param (builder, "descr", G_TYPE_STRING,
 									  TRUE));
 		}
 
@@ -652,14 +652,14 @@ browser_favorites_add (BrowserFavorites *bfav, guint session_id,
 		builder = gda_sql_builder_new (GDA_SQL_STATEMENT_DELETE);
 		gda_sql_builder_set_table (builder, FAVORDER_TABLE_NAME);
 		gda_sql_builder_set_where (builder,
-		      gda_sql_builder_add_cond (builder, 0, GDA_SQL_OPERATOR_TYPE_AND,
-			    gda_sql_builder_add_cond (builder, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-						  gda_sql_builder_add_id (builder, 0, "fav_id"),
-						  gda_sql_builder_add_param (builder, 0, "id", G_TYPE_INT, FALSE),
+		      gda_sql_builder_add_cond (builder, GDA_SQL_OPERATOR_TYPE_AND,
+			    gda_sql_builder_add_cond (builder, GDA_SQL_OPERATOR_TYPE_EQ,
+						  gda_sql_builder_add_id (builder, "fav_id"),
+						  gda_sql_builder_add_param (builder, "id", G_TYPE_INT, FALSE),
 						  0),
-			    gda_sql_builder_add_cond (builder, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-						  gda_sql_builder_add_id (builder, 0, "order_key"),
-						  gda_sql_builder_add_param (builder, 0, "orderkey", G_TYPE_INT, FALSE),
+			    gda_sql_builder_add_cond (builder, GDA_SQL_OPERATOR_TYPE_EQ,
+						  gda_sql_builder_add_id (builder, "order_key"),
+						  gda_sql_builder_add_param (builder, "orderkey", G_TYPE_INT, FALSE),
 						  0), 0));
 		stmt = gda_sql_builder_get_statement (builder, error);
 		g_object_unref (G_OBJECT (builder));
@@ -674,14 +674,14 @@ browser_favorites_add (BrowserFavorites *bfav, guint session_id,
 		builder = gda_sql_builder_new (GDA_SQL_STATEMENT_INSERT);
 		gda_sql_builder_set_table (builder, FAVORDER_TABLE_NAME);
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "fav_id"),
-					   gda_sql_builder_add_param (builder, 0, "id", G_TYPE_INT, FALSE));
+					   gda_sql_builder_add_id (builder, "fav_id"),
+					   gda_sql_builder_add_param (builder, "id", G_TYPE_INT, FALSE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "rank"),
-					   gda_sql_builder_add_param (builder, 0, "rank", G_TYPE_INT, FALSE));
+					   gda_sql_builder_add_id (builder, "rank"),
+					   gda_sql_builder_add_param (builder, "rank", G_TYPE_INT, FALSE));
 		gda_sql_builder_add_field_id (builder,
-					   gda_sql_builder_add_id (builder, 0, "order_key"),
-					   gda_sql_builder_add_param (builder, 0, "orderkey", G_TYPE_STRING, TRUE));
+					   gda_sql_builder_add_id (builder, "order_key"),
+					   gda_sql_builder_add_param (builder, "orderkey", G_TYPE_STRING, TRUE));
 		stmt = gda_sql_builder_get_statement (builder, error);
 		g_object_unref (G_OBJECT (builder));
 		if (!stmt)
@@ -792,37 +792,37 @@ browser_favorites_list (BrowserFavorites *bfav, guint session_id, BrowserFavorit
 
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_SELECT);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "fav.contents"), 0);
+				   gda_sql_builder_add_id (b, "fav.contents"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "fav.descr"), 0);
+				   gda_sql_builder_add_id (b, "fav.descr"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "fav.name"), 0);
+				   gda_sql_builder_add_id (b, "fav.name"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "fav.type"), 0);
+				   gda_sql_builder_add_id (b, "fav.type"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "fav.id"), 0);
+				   gda_sql_builder_add_id (b, "fav.id"), 0);
 
 	t1 = gda_sql_builder_select_add_target (b, FAVORITES_TABLE_NAME, "fav");
 	if (order_key > 0) {
 		t2 = gda_sql_builder_select_add_target (b, FAVORDER_TABLE_NAME, "o");
-		gda_sql_builder_select_join_targets (b, 0, t1, t2, GDA_SQL_SELECT_JOIN_LEFT,
-						     gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-									   gda_sql_builder_add_id (b, 0, "fav.id"),
-									   gda_sql_builder_add_id (b, 0, "o.fav_id"),
+		gda_sql_builder_select_join_targets (b, t1, t2, GDA_SQL_SELECT_JOIN_LEFT,
+						     gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+									   gda_sql_builder_add_id (b, "fav.id"),
+									   gda_sql_builder_add_id (b, "o.fav_id"),
 									   0));
 		gda_sql_builder_select_order_by (b,
-						 gda_sql_builder_add_id (b, 0, "o.rank"), TRUE, NULL);
+						 gda_sql_builder_add_id (b, "o.rank"), TRUE, NULL);
 
-		and_cond_ids [and_cond_size] = gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-							     gda_sql_builder_add_id (b, 0, "o.order_key"),
-							     gda_sql_builder_add_param (b, 0, "okey", G_TYPE_INT, FALSE),
+		and_cond_ids [and_cond_size] = gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+							     gda_sql_builder_add_id (b, "o.order_key"),
+							     gda_sql_builder_add_param (b, "okey", G_TYPE_INT, FALSE),
 							     0);
 		and_cond_size++;
 	}
 
-	and_cond_ids [and_cond_size] = gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-						     gda_sql_builder_add_id (b, 0, "fav.session"),
-						     gda_sql_builder_add_param (b, 0, "session", G_TYPE_INT, FALSE), 0);
+	and_cond_ids [and_cond_size] = gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+						     gda_sql_builder_add_id (b, "fav.session"),
+						     gda_sql_builder_add_param (b, "session", G_TYPE_INT, FALSE), 0);
 	and_cond_size++;
 
 	gint i;
@@ -831,26 +831,27 @@ browser_favorites_list (BrowserFavorites *bfav, guint session_id, BrowserFavorit
 		if (type & flag) {
 			gchar *str;
 			str = g_strdup_printf ("'%s'", favorite_type_to_string (flag));
-			or_cond_ids [or_cond_size] = gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-							     gda_sql_builder_add_id (b, 0, "fav.type"),
-							     gda_sql_builder_add_id (b, 0, str),
+			or_cond_ids [or_cond_size] = gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+							     gda_sql_builder_add_id (b, "fav.type"),
+							     gda_sql_builder_add_id (b, str),
 							     0);
 			g_free (str);
 			or_cond_size++;
 		}
 	}
 	if (or_cond_size >= 1) {
-		and_cond_ids [and_cond_size] = gda_sql_builder_add_cond_v (b, 0, GDA_SQL_OPERATOR_TYPE_OR,
+		and_cond_ids [and_cond_size] = gda_sql_builder_add_cond_v (b, GDA_SQL_OPERATOR_TYPE_OR,
 								       or_cond_ids, or_cond_size);
 		and_cond_size++;
 	}
 
 	gda_sql_builder_set_where (b,
-				   gda_sql_builder_add_cond_v (b, 0, GDA_SQL_OPERATOR_TYPE_AND, and_cond_ids, and_cond_size));
+				   gda_sql_builder_add_cond_v (b, GDA_SQL_OPERATOR_TYPE_AND, and_cond_ids, and_cond_size));
 #ifdef GDA_DEBUG_NO
 	{
 		GdaSqlStatement *sqlst;
-		sqlst = gda_sql_builder_get_sql_statement (b, TRUE);
+		sqlst = gda_sql_builder_get_sql_statement (b);
+                
 		g_print ("=>%s\n", gda_sql_statement_serialize (sqlst));
 	}
 #endif
@@ -973,9 +974,9 @@ browser_favorites_delete (BrowserFavorites *bfav, guint session_id,
 	/* remove entry from favorites' list */
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_DELETE);
 	gda_sql_builder_set_table (b, FAVORITES_TABLE_NAME);
-	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-							    gda_sql_builder_add_id (b, 0, "id"),
-							    gda_sql_builder_add_param (b, 0, "id", G_TYPE_INT, FALSE),
+	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+							    gda_sql_builder_add_id (b, "id"),
+							    gda_sql_builder_add_param (b, "id", G_TYPE_INT, FALSE),
 							    0));
 
 	stmt = gda_sql_builder_get_statement (b, error);
@@ -995,9 +996,9 @@ browser_favorites_delete (BrowserFavorites *bfav, guint session_id,
 	/* remove entry from favorites' order */
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_DELETE);
 	gda_sql_builder_set_table (b, FAVORDER_TABLE_NAME);
-	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-							    gda_sql_builder_add_id (b, 0, "fav_id"),
-							    gda_sql_builder_add_param (b, 0, "id", G_TYPE_INT, FALSE),
+	gda_sql_builder_set_where (b, gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+							    gda_sql_builder_add_id (b, "fav_id"),
+							    gda_sql_builder_add_param (b, "id", G_TYPE_INT, FALSE),
 							    0));
 
 	stmt = gda_sql_builder_get_statement (b, error);
@@ -1085,21 +1086,21 @@ browser_favorites_get (BrowserFavorites *bfav, gint fav_id,
 
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_SELECT);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "id"), 0);
+				   gda_sql_builder_add_id (b, "id"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "type"), 0);
+				   gda_sql_builder_add_id (b, "type"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "name"), 0);
+				   gda_sql_builder_add_id (b, "name"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "descr"), 0);
+				   gda_sql_builder_add_id (b, "descr"), 0);
 	gda_sql_builder_add_field_id (b,
-				   gda_sql_builder_add_id (b, 0, "contents"), 0);
+				   gda_sql_builder_add_id (b, "contents"), 0);
 	gda_sql_builder_select_add_target (b, FAVORITES_TABLE_NAME, NULL);
 
 	gda_sql_builder_set_where (b,
-				   gda_sql_builder_add_cond (b, 0, GDA_SQL_OPERATOR_TYPE_EQ,
-							 gda_sql_builder_add_id (b, 0, "id"),
-						     gda_sql_builder_add_param (b, 0, "id", G_TYPE_INT, FALSE), 0));
+				   gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ,
+							 gda_sql_builder_add_id (b, "id"),
+						     gda_sql_builder_add_param (b, "id", G_TYPE_INT, FALSE), 0));
 	stmt = gda_sql_builder_get_statement (b, error);
 	g_object_unref (G_OBJECT (b));
 	if (!stmt)
