@@ -64,6 +64,8 @@ static void connection_busy_cb (BrowserConnection *bcnc, gboolean is_busy, gchar
 static void connection_added_cb (BrowserCore *bcore, BrowserConnection *bcnc, BrowserWindow *bwin);
 static void connection_removed_cb (BrowserCore *bcore, BrowserConnection *bcnc, BrowserWindow *bwin);
 
+static void transaction_status_changed_cb (BrowserConnection *bcnc, BrowserWindow *bwin);
+
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
@@ -78,6 +80,8 @@ struct _BrowserWindowPrivate {
 	GtkWidget         *spinner;
 	GtkUIManager      *ui_manager;
 	GtkActionGroup    *agroup;
+	GtkActionGroup    *perspectives_actions;
+	gboolean           updating_transaction_status;
 
 	GtkToolbarStyle    toolbar_style;
 	GtkActionGroup    *cnc_agroup; /* one GtkAction for each BrowserConnection */
@@ -138,6 +142,7 @@ browser_window_init (BrowserWindow *bwin)
 	bwin->priv->cnc_agroup = NULL;
 	bwin->priv->cnc_added_sigid = 0;
 	bwin->priv->cnc_removed_sigid = 0;
+	bwin->priv->updating_transaction_status = FALSE;
 }
 
 static void
@@ -165,8 +170,12 @@ browser_window_dispose (GObject *object)
 		if (bwin->priv->cnc_agroup)
 			g_object_unref (bwin->priv->cnc_agroup);
 
-		if (bwin->priv->bcnc)
+		if (bwin->priv->bcnc) {
+			g_signal_handlers_disconnect_by_func (bwin->priv->bcnc,
+							      G_CALLBACK (transaction_status_changed_cb),
+							      bwin);
 			g_object_unref (bwin->priv->bcnc);
+		}
 		if (bwin->priv->perspectives) {
 			g_slist_foreach (bwin->priv->perspectives, (GFunc) perspective_data_free, NULL);
 			g_slist_free (bwin->priv->perspectives);
@@ -189,8 +198,14 @@ delete_event (GtkWidget *widget, GdkEvent *event, BrowserWindow *bwin)
         return TRUE;
 }
 
+static void transaction_begin_cb (GtkAction *action, BrowserWindow *bwin);
+static void transaction_commit_cb (GtkAction *action, BrowserWindow *bwin);
+static void transaction_rollback_cb (GtkAction *action, BrowserWindow *bwin);
 static void quit_cb (GtkAction *action, BrowserWindow *bwin);
 static void about_cb (GtkAction *action, BrowserWindow *bwin);
+#ifdef HAVE_GDU
+static void manual_cb (GtkAction *action, BrowserWindow *bwin);
+#endif
 static void window_close_cb (GtkAction *action, BrowserWindow *bwin);
 static void window_fullscreen_cb (GtkToggleAction *action, BrowserWindow *bwin);
 static void window_new_cb (GtkAction *action, BrowserWindow *bwin);
@@ -211,7 +226,7 @@ static const GtkToggleActionEntry ui_toggle_actions [] =
 static const GtkActionEntry ui_actions[] = {
         { "Connection", NULL, "_Connection", NULL, "Connection", NULL },
         { "ConnectionOpen", GTK_STOCK_CONNECT, "_Connect", NULL, "Open a connection", G_CALLBACK (connection_open_cb)},
-        { "ConnectionBind", NULL, N_("_Bind connection"), "<control>V", N_("Use connection to create\n"
+        { "ConnectionBind", NULL, N_("_Bind connection"), "<control>I", N_("Use connection to create\n"
 						    "a new binding connection to access data\n"
 						    "from multiple databases at once"), G_CALLBACK (connection_bind_cb)},
         { "ConnectionProps", GTK_STOCK_PROPERTIES, "_Properties", NULL, "Connection properties", G_CALLBACK (connection_properties_cb)},
@@ -226,7 +241,16 @@ static const GtkActionEntry ui_actions[] = {
         { "WindowNewOthers", NULL, "New window for _connection", NULL, "Open a new window for a connection", NULL},
         { "WindowClose", GTK_STOCK_CLOSE, "_Close", "", "Close this window", G_CALLBACK (window_close_cb)},
         { "Help", NULL, "_Help", NULL, "Help", NULL },
-        { "HelpAbout", GTK_STOCK_ABOUT, "_About", NULL, "About", G_CALLBACK (about_cb) }
+        { "HelpAbout", GTK_STOCK_ABOUT, "_About", NULL, "About", G_CALLBACK (about_cb) },
+#ifdef HAVE_GDU
+        { "HelpManual", GTK_STOCK_HELP, "_Manual", "F1", "Manual", G_CALLBACK (manual_cb) },
+#endif
+	{ "TransactionBegin", BROWSER_STOCK_BEGIN, N_("Begin"), NULL, N_("Begin a new transaction"),
+          G_CALLBACK (transaction_begin_cb)},
+        { "TransactionCommit", BROWSER_STOCK_COMMIT, N_("Commit"), NULL, N_("Commit current transaction"),
+          G_CALLBACK (transaction_commit_cb)},
+        { "TransactionRollback", BROWSER_STOCK_ROLLBACK, N_("Rollback"), NULL, N_("Rollback current transaction"),
+          G_CALLBACK (transaction_rollback_cb)},
 };
 
 static const gchar *ui_actions_info =
@@ -241,6 +265,10 @@ static const gchar *ui_actions_info =
         "      <menuitem name='ConnectionBind' action= 'ConnectionBind'/>"
         "      <menuitem name='ConnectionClose' action= 'ConnectionClose'/>"
         "      <separator/>"
+	"      <menuitem name='TransactionBegin' action= 'TransactionBegin'/>"
+        "      <menuitem name='TransactionCommit' action= 'TransactionCommit'/>"
+        "      <menuitem name='TransactionRollback' action= 'TransactionRollback'/>"
+        "      <separator/>"
         "      <menuitem name='Quit' action= 'Quit'/>"
         "      <separator/>"
         "    </menu>"
@@ -261,12 +289,19 @@ static const gchar *ui_actions_info =
         "    </menu>"
 	"    <placeholder name='MenuExtension'/>"
         "    <menu name='Help' action='Help'>"
+#ifdef HAVE_GDU
+        "      <menuitem name='HelpManual' action= 'HelpManual'/>"
+#endif
         "      <menuitem name='HelpAbout' action= 'HelpAbout'/>"
         "    </menu>"
         "  </menubar>"
         "  <toolbar  name='ToolBar'>"
         "    <toolitem action='WindowClose'/>"
         "    <toolitem action='WindowFullScreen'/>"
+	"    <separator/>"
+        "    <toolitem action='TransactionBegin'/>"
+        "    <toolitem action='TransactionCommit'/>"
+        "    <toolitem action='TransactionRollback'/>"
         "  </toolbar>"
         "</ui>";
 
@@ -297,6 +332,9 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 
 	bwin = BROWSER_WINDOW (g_object_new (BROWSER_TYPE_WINDOW, NULL));
 	bwin->priv->bcnc = g_object_ref (bcnc);
+	g_signal_connect (bcnc, "transaction-status-changed",
+			  G_CALLBACK (transaction_status_changed_cb), bwin);
+
 	cncname = browser_connection_get_name (bcnc);
 	if (!cncname)
 		cncname = _("unnamed");
@@ -333,6 +371,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	bwin->priv->agroup = group;
         gtk_action_group_add_actions (group, ui_actions, G_N_ELEMENTS (ui_actions), bwin);
 	gtk_action_group_add_toggle_actions (group, ui_toggle_actions, G_N_ELEMENTS (ui_toggle_actions), bwin);
+	transaction_status_changed_cb (bwin->priv->bcnc, bwin);
 
         ui = gtk_ui_manager_new ();
         gtk_ui_manager_insert_action_group (ui, group, 0);
@@ -354,7 +393,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	bwin->priv->toolbar_style = gtk_toolbar_get_style (GTK_TOOLBAR (toolbar));
 
 	GtkToolItem *ti;
-	GtkWidget *spinner;
+	GtkWidget *spinner, *svbox, *align;
 
 	ti = gtk_separator_tool_item_new ();
 	gtk_separator_tool_item_set_draw (GTK_SEPARATOR_TOOL_ITEM (ti), FALSE);
@@ -363,8 +402,15 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
         gtk_widget_show (GTK_WIDGET (ti));
 
 	spinner = browser_spinner_new ();
+	browser_spinner_set_size ((BrowserSpinner*) spinner, GTK_ICON_SIZE_SMALL_TOOLBAR);
+
+	svbox = gtk_vbox_new (FALSE, 0);
+	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	gtk_container_add (GTK_CONTAINER (align), spinner);
+	gtk_box_pack_start (GTK_BOX (svbox), align, TRUE, TRUE, 0);
+
 	ti = gtk_tool_item_new  ();
-	gtk_container_add (GTK_CONTAINER (ti), spinner);
+	gtk_container_add (GTK_CONTAINER (ti), svbox);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), ti, -1);
         gtk_widget_show_all (GTK_WIDGET (ti));
 	bwin->priv->spinner = spinner;
@@ -424,6 +470,7 @@ browser_window_new (BrowserConnection *bcnc, BrowserPerspectiveFactory *factory)
 	mid = gtk_ui_manager_new_merge_id (bwin->priv->ui_manager);
 	agroup = gtk_action_group_new ("Perspectives");
 	gtk_ui_manager_insert_action_group (bwin->priv->ui_manager, agroup, 0);
+	bwin->priv->perspectives_actions = agroup;
 	g_object_unref (agroup);
 
 	GtkAction *active_action = NULL;
@@ -560,6 +607,20 @@ connection_busy_cb (BrowserConnection *bcnc, gboolean is_busy, gchar *reason, Br
 	action = gtk_action_group_get_action (bwin->priv->agroup, "ConnectionMetaSync");
 	gtk_action_set_sensitive (action, !is_busy);
 
+	gboolean bsens = FALSE, csens = FALSE;
+	if (!is_busy) {
+		if (browser_connection_get_transaction_status (bcnc))
+			csens = TRUE;
+		else
+			bsens = TRUE;
+	}
+	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionBegin");
+	gtk_action_set_sensitive (action, bsens);
+	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionCommit");
+	gtk_action_set_sensitive (action, csens);
+	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionRollback");
+	gtk_action_set_sensitive (action, csens);	
+
 	const gchar *cncname;
 	cncname = browser_connection_get_name (bcnc);
 	action = gtk_action_group_get_action (bwin->priv->cnc_agroup, cncname);
@@ -705,6 +766,73 @@ quit_cb (GtkAction *action, BrowserWindow *bwin)
 	gtk_widget_destroy (dialog);	
 }
 
+static void
+transaction_status_changed_cb (BrowserConnection *bcnc, BrowserWindow *bwin)
+{
+	if (!bwin->priv->agroup)
+		return;
+
+	GtkAction *action;
+	gboolean trans_started;
+
+	trans_started = browser_connection_get_transaction_status (bcnc) ? TRUE : FALSE;
+	bwin->priv->updating_transaction_status = TRUE;
+
+	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionBegin");
+	gtk_action_set_sensitive (action, !trans_started);
+
+	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionCommit");
+	gtk_action_set_sensitive (action, trans_started);
+
+	action = gtk_action_group_get_action (bwin->priv->agroup, "TransactionRollback");
+	gtk_action_set_sensitive (action, trans_started);
+				      
+	bwin->priv->updating_transaction_status = FALSE;
+}
+
+static void
+transaction_begin_cb (GtkAction *action, BrowserWindow *bwin)
+{
+	if (!bwin->priv->updating_transaction_status) {
+		GError *error = NULL;
+		if (! browser_connection_begin (bwin->priv->bcnc, &error)) {
+			browser_show_error (GTK_WINDOW (gtk_widget_get_toplevel ((GtkWidget*) bwin)),
+					    _("Error starting transaction: %s"),
+					    error && error->message ? error->message : _("No detail"));
+			g_clear_error (&error);
+		}
+	}
+}
+
+static void
+transaction_commit_cb (GtkAction *action, BrowserWindow *bwin)
+{
+	if (!bwin->priv->updating_transaction_status) {
+		GError *error = NULL;
+		if (! browser_connection_commit (bwin->priv->bcnc, &error)) {
+			browser_show_error (GTK_WINDOW (gtk_widget_get_toplevel ((GtkWidget*) bwin)),
+					    _("Error committing transaction: %s"),
+					    error && error->message ? error->message : _("No detail"));
+			g_clear_error (&error);
+		}
+	}
+}
+
+static void
+transaction_rollback_cb (GtkAction *action, BrowserWindow *bwin)
+{
+	if (!bwin->priv->updating_transaction_status) {
+		GError *error = NULL;
+		if (! browser_connection_rollback (bwin->priv->bcnc, &error)) {
+			browser_show_error (GTK_WINDOW (gtk_widget_get_toplevel ((GtkWidget*) bwin)),
+					    _("Error rolling back transaction: %s"),
+					    error && error->message ? error->message : _("No detail"));
+			g_clear_error (&error);
+		}
+	}
+}
+
+
 static void
 window_close_cb (GtkAction *action, BrowserWindow *bwin)
 {
@@ -890,7 +1018,7 @@ about_cb (GtkAction *action, BrowserWindow *bwin)
         g_free (path);
 
         dialog = gtk_about_dialog_new ();
-        gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (dialog), _("Database browser"));
+	gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG (dialog), _("Database browser"));
         gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (dialog), PACKAGE_VERSION);
         gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (dialog), "(C) 2009 GNOME Foundation");
 	gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (dialog), _("Database access services for the GNOME Desktop"));
@@ -907,6 +1035,15 @@ about_cb (GtkAction *action, BrowserWindow *bwin)
         gtk_widget_show (dialog);
 }
 
+#ifdef HAVE_GDU
+void
+manual_cb (GtkAction *action, BrowserWindow *bwin)
+{
+	browser_show_help (GTK_WINDOW (bwin), NULL);
+}
+#endif
+
+
 /**
  * browser_window_get_connection
  * @bwin: a #BrowserWindow
@@ -1093,3 +1230,54 @@ browser_window_customize_perspective_ui (BrowserWindow *bwin, BrowserPerspective
 										-1, NULL);
 	}
 }
+
+/**
+ * browser_window_change_perspective
+ * @bwin: a #BrowserWindow
+ * @perspective: the name of the perspective to change to
+ *
+ * Make @bwin switch to the perspective named @perspective
+ *
+ * Returns: a pointer to the #BrowserPerspective, or %NULL if not found
+ */
+BrowserPerspective *
+browser_window_change_perspective (BrowserWindow *bwin, const gchar *perspective)
+{
+	BrowserPerspectiveFactory *bpf;
+	BrowserPerspective *bpers = NULL;
+	PerspectiveData *current_pdata;
+
+	g_return_val_if_fail (BROWSER_IS_WINDOW (bwin), NULL);
+	g_return_val_if_fail (perspective, NULL);
+
+	current_pdata = bwin->priv->current_perspective;
+
+	bpf = browser_core_get_factory (perspective);
+	if (!bpf)
+		return NULL;
+	GList *actions, *list;
+	actions = gtk_action_group_list_actions (bwin->priv->perspectives_actions);
+	for (list = actions; list; list = list->next) {
+		GtkAction *action = (GtkAction *) list->data;
+		BrowserPerspectiveFactory *pf;
+		pf = BROWSER_PERSPECTIVE_FACTORY (g_object_get_data (G_OBJECT (action), "pers"));
+		if (pf == bpf) {
+			gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
+			PerspectiveData *pdata = bwin->priv->current_perspective;
+			if (pdata && ! g_ascii_strcasecmp (pdata->factory->perspective_name, perspective))
+				bpers = pdata->perspective_widget;
+			break;
+		}
+	}
+	g_list_free (actions);
+
+	browser_show_notice (GTK_WINDOW (bwin), "Perspective change",
+			     _("The current perspective has changed to the '%s' perspective, you "
+			       "can switch back to previous perspective through the "
+			       "'Perspective/%s' menu, or using the '%s' shortcut"),
+			     bwin->priv->current_perspective->factory->perspective_name,
+			     current_pdata->factory->perspective_name,
+			     current_pdata->factory->menu_shortcut);
+
+	return bpers;
+}
