@@ -347,11 +347,11 @@ canvas_entity_popup_func (BrowserCanvasTable *ce)
 	menu = gtk_menu_new ();
 	entry = gtk_menu_item_new_with_label (_("Remove"));
 	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (popup_func_delete_cb), ce);
-	gtk_menu_append (GTK_MENU (menu), entry);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), entry);
 	gtk_widget_show (entry);
 	entry = gtk_menu_item_new_with_label (_("Add referenced tables"));
 	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (popup_func_add_depend_cb), ce);
-	gtk_menu_append (GTK_MENU (menu), entry);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), entry);
 	gtk_widget_show (entry);
 
 	return menu;
@@ -512,7 +512,7 @@ build_context_menu (BrowserCanvas *canvas)
 	menu = gtk_menu_new ();
 	submitem = gtk_menu_item_new_with_label (_("Add table"));
 	gtk_widget_show (submitem);
-	gtk_menu_append (menu, submitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), submitem);
 	g_signal_connect (G_OBJECT (submitem), "activate", G_CALLBACK (popup_add_table_cb), canvas);
 
 	return menu;
@@ -647,3 +647,60 @@ browser_canvas_db_relations_select_table (BrowserCanvasDbRelations *canvas,
 	browser_canvas_item_toggle_select (BROWSER_CANVAS (canvas), (BrowserCanvasItem*) table);
 }
 
+/**
+ * browser_canvas_db_relations_items_to_data_manager
+ */
+gchar *
+browser_canvas_db_relations_items_to_data_manager (BrowserCanvasDbRelations *canvas)
+{
+	gchar *retval = NULL;
+	GSList *list;
+	xmlDocPtr doc;
+	xmlNodePtr topnode;
+
+	g_return_val_if_fail (IS_BROWSER_CANVAS (canvas), NULL);
+	
+	/* create XML doc and root node */
+	doc = xmlNewDoc (BAD_CAST "1.0");
+	topnode = xmlNewDocNode (doc, NULL, BAD_CAST "data", NULL);
+        xmlDocSetRootElement (doc, topnode);
+	
+	/* actually serialize all the items which can be serialized */
+	for (list = BROWSER_CANVAS (canvas)->priv->items; list; list = list->next) {
+                BrowserCanvasItem *item = BROWSER_CANVAS_ITEM (list->data);
+		GdaMetaTable *mtable;
+
+		mtable = g_hash_table_lookup (canvas->priv->hash_tables, item);
+		if (mtable) {
+			xmlNodePtr node;
+			node = xmlNewChild (topnode, NULL, BAD_CAST "table", NULL);
+			xmlSetProp (node, BAD_CAST "name",
+				    BAD_CAST GDA_META_DB_OBJECT (mtable)->obj_short_name);
+
+			GSList *fklist;
+			for (fklist = mtable->fk_list; fklist; fklist = fklist->next) {
+				GdaMetaTableForeignKey *fk = (GdaMetaTableForeignKey*) fklist->data;
+				GooCanvasItem *fk_item;
+				
+				fk_item = g_hash_table_lookup (canvas->priv->hash_fkeys, fk);
+				if (fk_item) {
+					node = xmlNewChild (node, NULL, BAD_CAST "depend", NULL);
+					xmlSetProp (node, BAD_CAST "foreign_key_table",
+						    BAD_CAST fk->depend_on->obj_short_name);
+				}
+			}
+
+		}
+	}
+
+	/* create buffer from XML tree */
+	xmlChar *xstr = NULL;
+	xmlDocDumpFormatMemory (doc, &xstr, NULL, 1);
+	if (xstr) {
+		retval = g_strdup ((gchar *) xstr);
+		xmlFree (xstr);
+	}
+	xmlFreeDoc (doc);
+	
+	return retval;	
+}
