@@ -1,5 +1,5 @@
-/* GDA Postgres Provider
- * Copyright (C) 2008 The GNOME Foundation
+/*
+ * Copyright (C) 2009 The GNOME Foundation
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -30,6 +30,7 @@ BrowserPerspectiveFactory *
 dummy_perspective_get_factory (void)
 {
 	bfact.perspective_name = "Dummy Perspective";
+	bfact.menu_shortcut = NULL;
 	bfact.perspective_create = dummy_perspective_new;
 
 	return &bfact;
