@@ -29,7 +29,7 @@ static BrowserPerspectiveFactory bfact;
 BrowserPerspectiveFactory *
 query_exec_perspective_get_factory (void)
 {
-	bfact.perspective_name = "Query execution";
+	bfact.perspective_name = "Query execution (SQL)";
 	bfact.menu_shortcut = "<control>S";
 	bfact.perspective_create = query_exec_perspective_new;
 
